#ifdef STM32F4xx
  #include "stm32f4xx_hal_flash_ramfunc.c"
#endif
#ifdef STM32G4xx
  #include "stm32g4xx_hal_flash_ramfunc.c"
#endif
#ifdef STM32L0xx
  #include "stm32l0xx_hal_flash_ramfunc.c"
#endif
#ifdef STM32L1xx
  #include "stm32l1xx_hal_flash_ramfunc.c"
#endif
#ifdef STM32L4xx
  #include "stm32l4xx_hal_flash_ramfunc.c"
#endif
#ifdef STM32L5xx
  #include "stm32l5xx_hal_flash_ramfunc.c"
#endif
